import{C as t,E as d,K as i,a as b,M as c,c as l,P as y,R as f,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.63b27be7.js";import"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="183103ad-d163-4131-a91c-e29ee902b7b2",e._sentryDebugIdIdentifier="sentry-dbid-183103ad-d163-4131-a91c-e29ee902b7b2")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,b as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,f as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.aaaea116.js.map
