import{i as h}from"./metadata.a4a483e2.js";import{W as k}from"./Watermark.3739d48d.js";import{F as v}from"./PhArrowSquareOut.vue.cb1204cb.js";import{d as w,e5 as b,c as x,r as C,u as e,a5 as f,f as d,b as r,h as D,o as a,a as n,g as m,T as y,aR as I,eb as z,de as _,ee as T,ec as F,e9 as B,_ as H}from"./jwt-decode.esm.febfd28e.js";import{u as L}from"./workspaceStore.2666ff60.js";import"./index.23075af0.js";import{L as N}from"./LoadingOutlined.501b6fdc.js";import{C as S}from"./Card.ef0393b5.js";import"./PhWebhooksLogo.vue.c48d82e4.js";import"./index.10c90e84.js";import"./constants.48af5f1d.js";import"./userStore.eacc1229.js";import"./url.092f6baf.js";import"./colorHelpers.e47d6f05.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="5f41e227-7000-40c4-9544-a78d126ffa65",o._sentryDebugIdIdentifier="sentry-dbid-5f41e227-7000-40c4-9544-a78d126ffa65")}catch{}})();const V={key:0,class:"home-container"},W=w({__name:"Home",setup(o){const i=b(),l=L(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(p=>p.id!=="home"))||[]}),c=C(null),g=async(s,p)=>{c.value=p,await i.push({path:`/${s}`}),c.value=null};return(s,p)=>e(l).state.workspace?(a(),f("div",V,[d(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[m(" There are no forms available for you. ")]),_:1})):(a(!0),f(I,{key:1},z(u.value,t=>(a(),n(e(S),{key:t.id,class:B(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(t.path,t.id)},{default:r(()=>[d(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(T(e(h)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),d(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[m(F(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(v),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),d(k,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Y=H(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.a4b70d60.js.map
