import{_ as c,o,a5 as n,a7 as s,e as a,h as d}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b60aa0ac-5f93-4f6f-8c18-9c8a06b03836",e._sentryDebugIdIdentifier="sentry-dbid-b60aa0ac-5f93-4f6f-8c18-9c8a06b03836")}catch{}})();const r={},f={class:"base-layout"},i={class:"base-middle"},_={class:"content"},l={class:"left"},u={key:0,class:"base-footer"},b={key:0};function y(e,t){return o(),n("div",f,[s(e.$slots,"sidebar",{},void 0,!0),a("section",i,[s(e.$slots,"navbar",{},void 0,!0),a("section",_,[a("section",l,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),n("section",u,[s(e.$slots,"footer",{},void 0,!0)])):d("",!0)]),e.$slots.chat?(o(),n("section",b,[s(e.$slots,"chat",{},void 0,!0)])):d("",!0)])])])}const g=c(r,[["render",y],["__scopeId","data-v-fe23e6dd"]]);export{g as B};
//# sourceMappingURL=BaseLayout.7f294166.js.map
