import{b as d}from"./constants.48af5f1d.js";import{f,e7 as i,d as b,o as c,a as p,b as l,u as o,a7 as m,a5 as g,g as h,aR as y,bR as O}from"./jwt-decode.esm.febfd28e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="eea6fcef-e338-48a2-a85c-5d45394db3f0",t._sentryDebugIdIdentifier="sentry-dbid-eea6fcef-e338-48a2-a85c-5d45394db3f0")}catch{}})();var v={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V96c0-17.7-14.3-32-32-32zm-260 72h96v209.9L621.5 312 572 347.4V136zm220 752H232V136h280v296.9c0 3.3 1 6.6 3 9.3a15.9 15.9 0 0022.3 3.7l83.8-59.9 81.4 59.4c2.7 2 6 3.1 9.4 3.1 8.8 0 16-7.2 16-16V136h64v752z"}}]},name:"book",theme:"outlined"};const _=v;function u(t){for(var e=1;e<arguments.length;e++){var n=arguments[e]!=null?Object(arguments[e]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){k(t,a,n[a])})}return t}function k(t,e,n){return e in t?Object.defineProperty(t,e,{value:n,enumerable:!0,configurable:!0,writable:!0}):t[e]=n,t}var s=function(e,n){var r=u({},e,n.attrs);return f(i,u({},r,{icon:_}),null)};s.displayName="BookOutlined";s.inheritAttrs=!1;const B=s,I=b({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>(c(),p(o(O),{class:"docs-button",href:o(d)(e.path),target:"_blank",type:"text",size:"small"},{icon:l(()=>[f(o(B))]),default:l(()=>[e.$slots.default?m(e.$slots,"default",{key:0}):(c(),g(y,{key:1},[h("Docs")],64))]),_:3},8,["href"]))}});export{I as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.70530128.js.map
