.otp-input[data-v-7ff63456]{padding:2px;padding-inline-start:2px}.otp-input[data-v-7ff63456] .ant-input{text-align:center}.otp-input[data-v-7ff63456] .ant-input-suffix{display:none}.container[data-v-174df194]{display:flex;gap:10px}
