import{O as r}from"./index.10c90e84.js";import{d as l,k as i,a5 as c,f as t,b as n,u as d,o as u,g as o,A as f,da as _}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="72ec7ddd-8f33-4c8c-a343-3af78ad56152",e._sentryDebugIdIdentifier="sentry-dbid-72ec7ddd-8f33-4c8c-a343-3af78ad56152")}catch{}})();const b=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(a,s)=>(u(),c("div",null,[t(d(f),null,{default:n(()=>[o("You're authenticated")]),_:1}),t(d(_),null,{default:n(()=>[o(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLoginCallback.2d17c95e.js.map
