import{d,o,a5 as s,f as a,u as _,S as r,_ as i}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="3e917b03-22d1-4d01-b5d2-404330058713",e._sentryDebugIdIdentifier="sentry-dbid-3e917b03-22d1-4d01-b5d2-404330058713")}catch{}})();const c={class:"centered"},f=d({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",c,[a(_(r))]))}});const u=i(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.fcc58b23.js.map
