import"./jwt-decode.esm.febfd28e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="387a8bdc-1f92-4279-9c59-df8b1e8db2ae",t._sentryDebugIdIdentifier="sentry-dbid-387a8bdc-1f92-4279-9c59-df8b1e8db2ae")}catch{}})();const s={HOMEPAGE:"https://abstra.io",DOCS:"https://abstra.io/docs",CLOUD:"https://cloud.abstra.io",GITHUB:"https://github.com/abstra-app/abstra-lib"},a=t=>{if(!t)return s.DOCS;const e=t.startsWith("/")?t.slice(1):t;return`${s.DOCS}/${e}`};export{s as A,a as b};
//# sourceMappingURL=constants.48af5f1d.js.map
