import{A as a}from"./index.0d8ae5c8.js";import{d as o,c as r,a5 as p,f,u as d,e9 as c,h as l,o as i,_ as u}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e36e0c0f-1473-4d23-a99a-a8ad3709ae5f",e._sentryDebugIdIdentifier="sentry-dbid-e36e0c0f-1473-4d23-a99a-a8ad3709ae5f")}catch{}})();const _=o({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,m)=>t.stepsInfo?(i(),p("nav",{key:0,class:c(["p-steps",{"full-screen":!t.isPreview}])},[f(d(a),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):l("",!0)}});const b=u(_,[["__scopeId","data-v-8b0ea4f1"]]);export{b as S};
//# sourceMappingURL=Steps.f131345f.js.map
