import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.426f6b33.js";import{d as i,ea as s,a,u as m,o as d}from"./jwt-decode.esm.febfd28e.js";import"./router.f4c1fe8c.js";import"./index.ab72d4ab.js";import"./fetch.30d47f3a.js";import"./record.a977dda7.js";import"./SaveButton.dd7642fa.js";import"./ExclamationCircleOutlined.acc66f6d.js";import"./CrudView.5ea4f8e5.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.70530128.js";import"./constants.48af5f1d.js";import"./url.092f6baf.js";import"./PhDotsThreeVertical.vue.7bdc070f.js";import"./index.0e1a642f.js";import"./asyncComputed.f3fe22c0.js";import"./polling.4a7f8a79.js";import"./omniChatStore.51f8e32d.js";import"./uuid.220f2065.js";import"./PhCopySimple.vue.54bfebb2.js";import"./PhPencil.vue.a29e7db1.js";import"./index.2d1962d5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="df38510e-c567-4640-8da6-df374a010a32",o._sentryDebugIdIdentifier="sentry-dbid-df38510e-c567-4640-8da6-df374a010a32")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(c,f)=>(d(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.72c91d2b.js.map
