import{X as s,dL as d,dM as i}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2168b0ea-5f82-449b-aaac-cab7dd7b4cf6",e._sentryDebugIdIdentifier="sentry-dbid-2168b0ea-5f82-449b-aaac-cab7dd7b4cf6")}catch{}})();const{DatePicker:n,WeekPicker:a,MonthPicker:t,YearPicker:f,TimePicker:b,QuarterPicker:r,RangePicker:c}=d(i),u=s(n,{WeekPicker:a,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:b,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(a.name,a),e.component(r.name,r),e)});export{u as D,t as M,r as Q,c as R,a as W};
//# sourceMappingURL=dayjs.542b5c96.js.map
