import{d,ex as c,c as r,o,a5 as t,h as l,e9 as _,ec as p,_ as u}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ef1e70a3-ba81-4409-98e4-3116392958c0",e._sentryDebugIdIdentifier="sentry-dbid-ef1e70a3-ba81-4409-98e4-3116392958c0")}catch{}})();const g={class:"logo"},f=["src","alt"],m=d({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;c(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),i=r(()=>`${s.brandName} Logo`);return(a,y)=>(o(),t("div",g,[a.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:a.imageUrl,alt:i.value},null,8,f)):l("",!0),a.hideText?l("",!0):(o(),t("span",{key:1,class:_(a.size)},p(a.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.90e0032b.js.map
