import{P as f}from"./PlayerNavbar.05b77051.js";import{d as g,e5 as h,ea as c,r as b,c as y,m as k,a5 as v,u as n,a as w,h as L,e as C,f as I,o as i,_ as N}from"./jwt-decode.esm.febfd28e.js";import{u as V}from"./workspaceStore.2666ff60.js";import"./userStore.eacc1229.js";import"./index.10c90e84.js";import"./metadata.a4a483e2.js";import"./PhWebhooksLogo.vue.c48d82e4.js";import"./LoadingOutlined.501b6fdc.js";import"./PhSignOut.vue.5ed403e3.js";import"./index.2682b561.js";import"./url.092f6baf.js";import"./colorHelpers.e47d6f05.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="666aa85d-84db-4dac-9beb-3fcf8d640c17",o._sentryDebugIdIdentifier="sentry-dbid-666aa85d-84db-4dac-9beb-3fcf8d640c17")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,a=b(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(d),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const G=N(D,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main.4da3d4c1.js.map
