import{y as n,z as r,B as o,C as d,P as p,D as c,E as f,F as m,G as i,H as u,I as b,J as g,K as y}from"./jwt-decode.esm.febfd28e.js";import{a as l,b as a}from"./workspaceStore.2666ff60.js";import{s as w}from"./index.10c90e84.js";import{_ as I}from"./App.vue_vue_type_style_index_0_lang.35a46dc9.js";import"./userStore.eacc1229.js";import"./url.092f6baf.js";import"./colorHelpers.e47d6f05.js";import"./PlayerConfigProvider.24fc167a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="0d4251e0-2973-49f7-b611-7905b3e9e8e8",t._sentryDebugIdIdentifier="sentry-dbid-0d4251e0-2973-49f7-b611-7905b3e9e8e8")}catch{}})();class _{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const t=await l(),s=n(),e=r({render:()=>u(I)});o.init(),d(e,a,t),_.init(),e.use(a),e.use(s),e.use(p),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",f),e.component("Message",m),i(e,b),i(e,g),i(e,y)})();
//# sourceMappingURL=player.f1ae766b.js.map
