import{d as i,e5 as f,ea as m,o as l,a as p,b as u,a5 as _,eb as g,f as y,e as v,ec as k,u as n,aR as w}from"./jwt-decode.esm.febfd28e.js";import{A as I,T}from"./Card.ef0393b5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="565e8bea-ad16-4b8f-b6fd-7544347c0960",e._sentryDebugIdIdentifier="sentry-dbid-565e8bea-ad16-4b8f-b6fd-7544347c0960")}catch{}})();const R=i({__name:"TablesTabs",setup(e){const a=f(),t=m(),c=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(l(),p(n(T),{"active-key":n(c),options:r,"onUpdate:activeKey":b},{default:u(()=>[(l(),_(w,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:u(()=>[v("span",null,k(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{R as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.b6969f1d.js.map
