import{L as a}from"./Logo.90e0032b.js";import{d as n,o as r,a as d,u as i}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="9286e2ee-4d65-4b57-831a-99c6de04f596",e._sentryDebugIdIdentifier="sentry-dbid-9286e2ee-4d65-4b57-831a-99c6de04f596")}catch{}})();const f="/assets/logo.0faadfa2.svg",p=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return r(),d(a,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{p as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.02d28fa3.js.map
