import{f as c,e7 as o,eZ as f}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a8eb779f-f67c-4d99-b35b-811307275ea9",e._sentryDebugIdIdentifier="sentry-dbid-a8eb779f-f67c-4d99-b35b-811307275ea9")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){u(e,a,n[a])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=l({},t,n.attrs);return c(o,l({},r,{icon:f}),null)};i.displayName="ExclamationCircleOutlined";i.inheritAttrs=!1;const b=i;export{b as E};
//# sourceMappingURL=ExclamationCircleOutlined.acc66f6d.js.map
