.main-container[data-v-f095bece]{display:flex;flex-direction:column;height:100%}.main-container .content[data-v-f095bece]{width:100%;flex:1;overflow:hidden}.main-container .centered[data-v-f095bece]{display:flex;justify-content:center;align-items:center;height:100%}
