import{O as a}from"./OmniChat.1a696398.js";import{u as s}from"./omniChatStore.51f8e32d.js";import{d as c,ea as i,u as t,o as d,a as l,h as u}from"./jwt-decode.esm.febfd28e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b158095a-aa27-4078-9c78-9ee0dc932357",e._sentryDebugIdIdentifier="sentry-dbid-b158095a-aa27-4078-9c78-9ee0dc932357")}catch{}})();const b=c({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=s();return o.init("console",n),(p,m)=>t(o).controller&&t(o).repository?(d(),l(a,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.65495f15.js.map
