.disabled[data-v-aea27bb7]{opacity:.5;cursor:not-allowed}.preview[data-v-e1ac7894]{box-sizing:border-box;overflow:visible;min-width:fit-content;padding:2rem}.steps[data-v-e1ac7894]{margin-bottom:50px}.buttons[data-v-e1ac7894]{display:flex;flex-direction:row;gap:1rem;justify-content:flex-end;align-items:center;width:100%}.disable-events[data-v-e1ac7894]{pointer-events:none}
