import{d as a,a5 as d,e as s,a7 as l,e9 as n,o as r,_ as i}from"./jwt-decode.esm.febfd28e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="8e37d198-6489-4b6e-8017-2c871a700275",t._sentryDebugIdIdentifier="sentry-dbid-8e37d198-6489-4b6e-8017-2c871a700275")}catch{}})();const u=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,o)=>(r(),d("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[s("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[l(e.$slots,"default",{},void 0,!0)],2)],2))}});const f=i(u,[["__scopeId","data-v-fb4d67f9"]]);export{f as C};
//# sourceMappingURL=ContentLayout.9c270180.js.map
