import{h as a}from"./router.f4c1fe8c.js";import"./jwt-decode.esm.febfd28e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="5abbb812-9a4e-4c33-8e10-48e405af3703",t._sentryDebugIdIdentifier="sentry-dbid-5abbb812-9a4e-4c33-8e10-48e405af3703")}catch{}})();class i{async create(e){return a.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return a.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return a.get(`organizations/${e}/members`)}async get(e,n){return a.get(`organizations/${e}/members/${n}`)}async update(e,n,r){return a.patch(`organizations/${e}/members/${n}`,r)}}export{i as M};
//# sourceMappingURL=member.a8b95371.js.map
