import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.07e366ff.js";import{d as m,e5 as f,ea as g,a5 as y,f as b,u as n,o as w,_ as k}from"./jwt-decode.esm.febfd28e.js";import{u as h}from"./workspaceStore.2666ff60.js";import"./index.10c90e84.js";import"./CircularLoading.e504e673.js";import"./Logo.90e0032b.js";import"./string.f661edcd.js";import"./index.2d1962d5.js";import"./userStore.eacc1229.js";import"./url.092f6baf.js";import"./colorHelpers.e47d6f05.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="d84b210d-8202-45cc-85e5-9e01d62a571a",e._sentryDebugIdIdentifier="sentry-dbid-d84b210d-8202-45cc-85e5-9e01d62a571a")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return w(),y("div",v,[b(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const U=k(I,[["__scopeId","data-v-cb33c596"]]);export{U as default};
//# sourceMappingURL=Login.79cfefed.js.map
