import{u as r}from"./userStore.eacc1229.js";import{W as n}from"./PlayerConfigProvider.24fc167a.js";import{u as c}from"./workspaceStore.2666ff60.js";import{d as f,w as i,m as d,u as o,a as p,b as u,h as l,o as m,f as _}from"./jwt-decode.esm.febfd28e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="b43015e1-551b-4fd3-910f-9b7fdec48fb2",t._sentryDebugIdIdentifier="sentry-dbid-b43015e1-551b-4fd3-910f-9b7fdec48fb2")}catch{}})();const v=f({__name:"App",setup(t){const a=r(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(b,w)=>{const s=d("RouterView");return o(e).state.workspace?(m(),p(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[_(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{v as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.35a46dc9.js.map
